.. image:: https://raw.githubusercontent.com/cr0hn/festin/master/images/festin-logo-banner.png

`FestIN` is a power S3 bucket finder and content discover.


Install
=======

.. code-block:: console

    $ pip install festin

License
=======

This project is distributed under `BSD license <https://github.com/cr0hn/festin/blob/master/LICENSE>`_


